# Changelog

## [0.1.4] - 2024-03-XX

### Added
- Support for Pydantic v2 while maintaining compatibility with v1.10.21
- Fixed MaintenanceStatus model to handle both string and integer status values

## [0.1.3] - 2024-03-14

### Added
- Initial release
- Support for WhiteBit Public API v1, v2, and v4
- Support for Private API v4
- WebSocket client implementation
- Webhook support
